mailr12882 - /1.3/gui/user_functions/spin.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on June 07, 2011 - 16:46:
Author: bugman
Date: Tue Jun  7 16:46:46 2011
New Revision: 12882

URL: http://svn.gna.org/viewcvs/relax?rev=12882&view=rev
Log:
Fixes for the spin.copy() GUI user function element.

This still had remnants of the residue.copy() window.


Modified:
    1.3/gui/user_functions/spin.py

Modified: 1.3/gui/user_functions/spin.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/gui/user_functions/spin.py?rev=12882&r1=12881&r2=12882&view=diff
==============================================================================
--- 1.3/gui/user_functions/spin.py (original)
+++ 1.3/gui/user_functions/spin.py Tue Jun  7 16:46:46 2011
@@ -127,19 +127,19 @@
 
 
 class Copy_window(UF_window, Mol_res_spin):
     """The residue.copy() user function window."""
 
     # Some class variables.
     size_x = 700
     size_y = 600
-    frame_title = 'Copy a residue'
-    image_path = WIZARD_IMAGE_PATH + 'residue.png'
-    main_text = 'This dialog allows you to copy residues.'
-    title = 'Residue copy'
+    frame_title = 'Copy a spin'
+    image_path = WIZARD_IMAGE_PATH + 'spin.png'
+    main_text = 'This dialog allows you to copy spin.'
+    title = 'Spin copy'
 
 
     def add_uf(self, sizer):
         """Add the residue specific GUI elements.
 
         @param sizer:   A sizer object.
         @type sizer:    wx.Sizer instance
@@ -127,19 +127,19 @@
 
 class Copy_window(UF_window, Mol_res_spin):
-    """The residue.copy() user function window."""
+    """The spin.copy() user function window."""
 
     # Some class variables.
@@ -127,19 +127,19 @@
 
     def add_uf(self, sizer):
-        """Add the residue specific GUI elements.
+        """Add the spin specific GUI elements.
 
         @param sizer:   A sizer object.




Related Messages


Powered by MHonArc, Updated Tue Jun 07 17:40:02 2011